void AddTask_Resolution(	TString V0ReaderEventCutNumber 	= "8000000",
							TString V0ReaderPhotonCutNumber = "060084001001500000000",
							TString TaskEventCutnumber 		= "8000011",
							TString TaskPhotonCutnumber 	= "092092170008260400000",
							Bool_t IsMC = kTRUE, 
							Int_t IsHeavyIon = 0, 
							TString cutnumberAODBranch = "0000000060084001001500000",
							Bool_t doEtaShiftV0Reader = kFALSE 
                       ){
	
	//get the current analysis manager
	// ================= Load Librariers =================================
	gSystem->Load("libCore.so");  
	gSystem->Load("libTree.so");
	gSystem->Load("libGeom.so");
	gSystem->Load("libVMC.so");
	gSystem->Load("libPhysics.so");
	gSystem->Load("libMinuit");
	gSystem->Load("libSTEERBase");
	gSystem->Load("libESD");
	gSystem->Load("libAOD");
	gSystem->Load("libANALYSIS");
	gSystem->Load("libANALYSISalice");  
	gSystem->Load("libPWGGAGammaConv.so");
	gSystem->Load("libCDB.so");
	gSystem->Load("libSTEER.so");
	gSystem->Load("libSTEERBase.so");
	gSystem->Load("libTENDER.so");
	gSystem->Load("libTENDERSupplies.so");
		
	// ================== GetAnalysisManager ===============================
	AliAnalysisManager *mgr = AliAnalysisManager::GetAnalysisManager();
	if (!mgr) {
		Error(Form("AddTask_GammaConvV1_%i",trainConfig), "No analysis manager found.");
		return ;
	}

	// ================== GetInputEventHandler =============================
	AliVEventHandler *inputHandler=mgr->GetInputEventHandler();
	
	//========= Add PID Reponse to ANALYSIS manager ====
	if(!(AliPIDResponse*)mgr->GetTask("PIDResponseTask")){
		gROOT->LoadMacro("$ALICE_ROOT/ANALYSIS/macros/AddTaskPIDResponse.C");
		AddTaskPIDResponse(isMC);
	}

	AliAnalysisDataContainer *cinput = mgr->GetCommonInputContainer();
	if( !(AliV0ReaderV1*)mgr->GetTask("V0ReaderV1") ){
		AliV0ReaderV1 *fV0ReaderV1 = new AliV0ReaderV1("V0ReaderV1");
		
		fV0ReaderV1->SetUseOwnXYZCalculation(kTRUE);
		fV0ReaderV1->SetCreateAODs(kFALSE);// AOD Output
		fV0ReaderV1->SetUseAODConversionPhoton(kTRUE);

		if (!mgr) {
			Error("AddTask_V0ReaderV1", "No analysis manager found.");
			return;
		}

		AliConvEventCuts *fEventCuts=NULL;
		if(V0ReaderEventCutNumber!=""){
			fEventCuts= new AliConvEventCuts(V0ReaderEventCutNumber.Data(),V0ReaderEventCutNumber.Data());
			fEventCuts->SetPreSelectionCutFlag(kTRUE);
			if(fEventCuts->InitializeCutsFromCutString(V0ReaderEventCutNumber.Data())){
				fV0ReaderV1->SetEventCuts(fEventCuts);
				fEventCuts->SetFillCutHistograms("",kTRUE);
				if (IsHeavyIon==2){
					fEventCuts->SelectCollisionCandidates(AliVEvent::kINT7);
					fEventCuts->DoEtaShift(doEtaShiftV0Reader);
				}
			}
		}

		// Set AnalysisCut Number
		AliConversionPhotonCuts *fCuts=NULL;
		if(V0ReaderPhotonCutNumber!=""){
			fCuts= new AliConversionPhotonCuts(V0ReaderPhotonCutNumber.Data(),V0ReaderPhotonCutNumber.Data());
			fCuts->SetPreSelectionCutFlag(kTRUE);
			fCuts->SetIsHeavyIon(IsHeavyIon);
			if(fCuts->InitializeCutsFromCutString(V0ReaderPhotonCutNumber.Data())){
				fV0ReaderV1->SetConversionCuts(fCuts);
				fCuts->SetFillCutHistograms("",kTRUE);
			}
		}
		
		
		if(inputHandler->IsA()==AliAODInputHandler::Class()){
			// AOD mode
			fV0ReaderV1->SetDeltaAODBranchName(Form("GammaConv_%s_gamma",cutnumberAODBranch.Data()));
		}
		fV0ReaderV1->Init();

		AliLog::SetGlobalLogLevel(AliLog::kInfo);

		//connect input V0Reader
		mgr->AddTask(fV0ReaderV1);
		mgr->ConnectInput(fV0ReaderV1,0,cinput);

	} else {
		Error("AddTask_V0ReaderV1", "Cannot execute AddTask, V0ReaderV1 already exists.");
	}   

	AliConvEventCuts *analysisEventCuts = new AliConvEventCuts();
	analysisEventCuts->InitializeCutsFromCutString(TaskEventCutnumber.Data());
	analysisEventCuts->SetFillCutHistograms("",kFALSE);

	AliConversionPhotonCuts *analysisCuts = new AliConversionPhotonCuts();
	analysisCuts->InitializeCutsFromCutString(TaskPhotonCutnumber.Data());
	analysisCuts->SetFillCutHistograms("",kFALSE);

	AliAnalysisTaskResolution *fResolution= new AliAnalysisTaskResolution(Form("%s_%s_Resolution",(analysisEventCuts->GetCutNumber()).Data(), (analysisCuts->GetCutNumber()).Data()));
	fResolution->SetEventCuts(analysisEventCuts,IsHeavyIon);	
	fResolution->SetConversionCuts(analysisCuts,IsHeavyIon);
	fResolution->SetIsMC(IsMC);
	mgr->AddTask(fResolution);
	
	AliAnalysisDataContainer *coutput1 =
	mgr->CreateContainer(Form("GammaConvResolution_%s_%s", TaskEventCutnumber.Data(), TaskPhotonCutnumber.Data()), TList::Class(),
						AliAnalysisManager::kOutputContainer, Form("GammaConv_Resolution_%s_%s.root", TaskEventCutnumber.Data(), TaskPhotonCutnumber.Data()));

	AliAnalysisDataContainer *cinput1  = mgr->GetCommonInputContainer();
	mgr->ConnectInput(fResolution,  0, cinput1 );
	mgr->ConnectOutput (fResolution,  1, coutput1);
   //connect containers
	return;
}

